Struct amazon_sp_finances::models::fee_component::FeeComponent
source · [−]Expand description
FeeComponent : A fee associated with the event.
Fields
fee_type: Option<String>The type of fee. For more information about Selling on Amazon fees, see Selling on Amazon Fee Schedule on Seller Central. For more information about Fulfillment by Amazon fees, see FBA features, services and fees on Seller Central.
fee_amount: Option<Box<Currency>>Implementations
sourceimpl FeeComponent
impl FeeComponent
sourcepub fn new() -> FeeComponent
pub fn new() -> FeeComponent
A fee associated with the event.